docs.rs failed to build copt-solver-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
rust-copt-solver
COPT(杉数求解器)非官方的Rust API。 Unofficial Rust API for COPT (Cardinal Optimizer).
注意 / Notes
- 本封装库并非杉数科技有限公司官方支持。功能尚未完善。自担风险使用!
- This wrapper library is not officially supported by Cardinal Operations. Some features have not completed yet. Use at your own risk!
感谢 / Thanks
- 受到rust-gurobi项目启发。
- Inspired by the rust-gurobi project.